# pywxm

![PyPI - Version](https://img.shields.io/pypi/v/pywxm)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pywxm)
![PyPI - License](https://img.shields.io/pypi/l/pywxm)

A fully typed asyncio SDK for the [WeatherXM API](https://api.weatherxm.com/api/v1/docs/).

The SDK exposes a subset of the API with a focus around querying current and forecast weather data for a user's weather stations.
Basic rewards information for each station is also supported.
The SDK may be extended over time with other useful APIs.

An example of how to use the SDK can be found in [examples/example.py](examples/example.py).
The example can be run using the `pdm run example` command.
